@@ -1,4 +1,4 @@
-/* $Id: tvm-camera-device.h 2340 2007-01-11 23:11:32Z benny $ */
+/* $Id: tvm-camera-device.h 5215 2008-08-12 08:54:15Z kelnos $ */
 /*-
  * Copyright (c) 2007 Benedikt Meurer <benny@xfce.org>.
  *
@@ -22,7 +22,7 @@
 
 #include <thunar-volman/tvm-device.h>
 
-G_BEGIN_DECLS;
+G_BEGIN_DECLS
 
 gboolean tvm_camera_device_added (TvmPreferences *preferences,
                                   LibHalContext  *context,
@@ -30,6 +30,6 @@ gboolean tvm_camera_device_added (TvmPreferences *preferences,
                                   const gchar    *capability,
                                   GError        **error) G_GNUC_INTERNAL;
 
-G_END_DECLS;
+G_END_DECLS
 
 #endif /* !__TVM_CAMERA_DEVICE_H__ */
